
%--------------------------------------------------------------------
% THIS PROCEDURE COMPUTES THE INTEGRAL OVER A POLYGON OF A CONTINUOUS
% FUNCTION DEFINED BY THE m-FILE "fct2D.m". 
% IN THIS DEMO WE FIRST SUBDIVIDE IN SUBSQUARES THE SMALLER RECTANGLE 
% WITH SIDES PARALLEL TO THE AXIS "x" AND "y" AND CONTAINING THE AFORE-
% MENTED POLYGON.
% THEN WE USE THE BUILT IN FUNCTIONS "dblquad" AND "inpolygon" TO 
% COMPUTE THE INTEGRAL OF THE PORTION OF POLYGON CONTAINED IN EACH 
% SUBDIVISION. TO THIS PURPOSE WE USE THE CHARACTERISTIC FUNCTION (cf.
% THE PROCEDURE "integrnd2D.m").
% FINALLY WE SUM THE RESULTS TO ACHIEVE THE INTEGRAL OVER THE POLYGON.
%--------------------------------------------------------------------

%--------------------------------------------------------------------
% SETTINGS.
%--------------------------------------------------------------------
polygon_type=2;        % POLYGON TYPE (cf. "define_polygon.m").
function_type=7;       % FUNCTION TYPE. (cf. "fct2d.m).
number_subdivisions=3; % NUMBER OF SUBDIVISIONS FOR DIRECTION.
tol=10^(-13);          % DBLQUAD TOLERANCE.


%--------------------------------------------------------------------
% MAIN PROGRAM.
%--------------------------------------------------------------------
% DEFINING TOLERANCE.
tol_loc=tol/(number_subdivisions.^2);        
                                             
polygon_sides=define_polygon(polygon_type);  % DEFINING POLYGON.
                                              
x_sides=polygon_sides(:,1);
y_sides=polygon_sides(:,2);
                                             %------------------------
x_min=min(x_sides); x_max=max(x_sides);      % DEFINING RECTANGLE 
y_min=min(y_sides); y_max=max(y_sides);      % CONTAINING THE POLYGON.
                                             %------------------------
hx=(x_max-x_min)/number_subdivisions;        % DEFINING SUBDIVISIONS.
hy=(y_max-y_min)/number_subdivisions;

integral=0;

% -----------------------------------------
% COMPUTING INTEGRALS IN EACH SUBDIVISION.
% -----------------------------------------
for subdv_x_number_subdivisions=1:number_subdivisions
    for subdv_y_number_subdivisions=1:number_subdivisions
        x1=x_min+(subdv_x_number_subdivisions-1)*hx; x2=x_min+subdv_x_number_subdivisions*hx;
        y1=y_min+(subdv_y_number_subdivisions-1)*hy; y2=y_min+subdv_y_number_subdivisions*hy;
        integral_loc=dblquad(@integrnd2D,x1,x2,y1,y2,tol_loc,@quadl,polygon_sides,function_type);
        integral=integral+integral_loc;
    end
end

% -----------------------------------------
% SOME STATS.
% -----------------------------------------
fprintf('\n \t [SUBDIVISIONS (FOR EACH SIDE)]: %3.0f [RESULT]: %5.16f',number_subdivisions,integral);
